/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.ejb;

import java.rmi.RemoteException;
import java.util.Set;

import javax.ejb.SessionBean;
import javax.ejb.SessionContext;

import org.ow2.bonita.facade.def.majorElement.ActivityDefinition;
import org.ow2.bonita.facade.def.majorElement.DataFieldDefinition;
import org.ow2.bonita.facade.def.majorElement.PackageDefinition;
import org.ow2.bonita.facade.def.majorElement.ParticipantDefinition;
import org.ow2.bonita.facade.def.majorElement.ProcessDefinition;
import org.ow2.bonita.facade.exception.ActivityDefNotFoundException;
import org.ow2.bonita.facade.exception.ActivityNotFoundException;
import org.ow2.bonita.facade.exception.DataFieldNotFoundException;
import org.ow2.bonita.facade.exception.PackageNotFoundException;
import org.ow2.bonita.facade.exception.ParticipantNotFoundException;
import org.ow2.bonita.facade.exception.ProcessNotFoundException;
import org.ow2.bonita.facade.impl.StandardInternalAPIAccessorImpl;
import org.ow2.bonita.facade.internal.InternalQueryDefinitionAPI;
import org.ow2.bonita.facade.uuid.ActivityDefinitionUUID;
import org.ow2.bonita.facade.uuid.PackageDefinitionUUID;
import org.ow2.bonita.facade.uuid.ParticipantDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;


public class QueryDefinitionAPIBean implements InternalQueryDefinitionAPI, SessionBean {

  protected SessionContext ctx;

  protected InternalQueryDefinitionAPI queryDefinitionAPI;

  protected InternalQueryDefinitionAPI getAPI() {
    EJB2SecurityOwner.setUser(this.ctx.getCallerPrincipal().getName());
    if (this.queryDefinitionAPI == null) {
      this.queryDefinitionAPI = new StandardInternalAPIAccessorImpl().getQueryDefinitionAPI();
    }
    return this.queryDefinitionAPI;
  }


  public void ejbCreate() {

  }

  public void ejbActivate() throws RemoteException {

  }

  public void ejbPassivate() throws RemoteException {

  }

  public void ejbRemove() throws RemoteException {

  }

  public void setSessionContext(final SessionContext arg0) throws RemoteException {
    this.ctx = arg0;
  }

  public PackageDefinition getPackage(final String packageId, final String version, 
      final String queryList) throws PackageNotFoundException, RemoteException {
    return getAPI().getPackage(packageId, version, queryList);
  }
  public Set<ProcessDefinition> getProcesses(final String processId, final String version, 
      final String queryList) throws RemoteException {
    return getAPI().getProcesses(processId, version, queryList);
  }
  public PackageDefinition getLastPackage(final String packageId, 
      final String queryList) throws PackageNotFoundException, RemoteException {
    return getAPI().getLastPackage(packageId, queryList);
  }

  public ProcessDefinition getLastProcess(final String packageId, final String processId, 
      final String queryList) throws ProcessNotFoundException, RemoteException {
    return getAPI().getLastProcess(packageId, processId, queryList);
  }

  public PackageDefinition getPackage(final PackageDefinitionUUID packageDefinitionUUID, 
      final String queryList) throws PackageNotFoundException, RemoteException {
    return getAPI().getPackage(packageDefinitionUUID, queryList);
  }

  public Set<ProcessDefinition> getPackageProcesses(
      final PackageDefinitionUUID packageDefinitionUUID, 
      final String queryList) throws PackageNotFoundException, RemoteException {
    return getAPI().getPackageProcesses(packageDefinitionUUID, queryList);
  }

  public Set<PackageDefinition> getPackages(final String queryList) throws RemoteException {
    return getAPI().getPackages(queryList);
  }

  public Set<PackageDefinition> getPackages(final String packageId, final String queryList) throws RemoteException {
    return getAPI().getPackages(packageId, queryList);
  }

  public Set<PackageDefinition> getPackages(final PackageDefinition.PackageState state, 
      final String queryList) throws RemoteException {
    return getAPI().getPackages(state, queryList);
  }

  public Set<PackageDefinition> getPackages(final String packageId,
      final PackageDefinition.PackageState state, final String queryList) throws PackageNotFoundException, RemoteException {
    return getAPI().getPackages(packageId, state, queryList);
  }

  public ProcessDefinition getProcess(final ProcessDefinitionUUID processDefinitionUUID, 
      final String queryList) throws ProcessNotFoundException, RemoteException {
    return getAPI().getProcess(processDefinitionUUID, queryList);
  }

  public Set<ActivityDefinition> getProcessActivities(final ProcessDefinitionUUID
      processDefinitionUUID, final String queryList) throws ProcessNotFoundException, RemoteException {
    return getAPI().getProcessActivities(processDefinitionUUID, queryList);
  }

  public ActivityDefinition getProcessActivity(
      final ProcessDefinitionUUID processDefinitionUUID, final String activityId, 
      final String queryList) throws ProcessNotFoundException, ActivityNotFoundException, RemoteException {
    return getAPI().getProcessActivity(processDefinitionUUID, activityId, queryList);
  }

  public ActivityDefinitionUUID getProcessActivityId(
      final ProcessDefinitionUUID processDefinitionUUID, final String activityName, 
      final String queryList) throws ProcessNotFoundException, RemoteException {
    return getAPI().getProcessActivityId(processDefinitionUUID, activityName, queryList);
  }

  public ParticipantDefinition getProcessParticipant(
      final ProcessDefinitionUUID processDefinitionUUID, final String participantId, 
      final String queryList) throws ProcessNotFoundException, ParticipantNotFoundException, RemoteException {
    return getAPI().getProcessParticipant(processDefinitionUUID, participantId, queryList);
  }

  public ParticipantDefinitionUUID getProcessParticipantId(
      final ProcessDefinitionUUID processDefinitionUUID, final String participantName, 
      final String queryList) throws ProcessNotFoundException, RemoteException {
    return getAPI().getProcessParticipantId(processDefinitionUUID, participantName, queryList);
  }

  public Set<ParticipantDefinition> getProcessParticipants(final ProcessDefinitionUUID processDefinitionUUID, 
      final String queryList) throws ProcessNotFoundException, RemoteException {
    return getAPI().getProcessParticipants(processDefinitionUUID, queryList);
  }

  public Set<ProcessDefinition> getProcesses(final String queryList) throws RemoteException {
    return getAPI().getProcesses(queryList);
  }

  public Set<ProcessDefinition> getPackageProcesses(final String packageId, final String processId, 
      final String queryList) throws RemoteException {
    return getAPI().getPackageProcesses(packageId, processId, queryList);
  }

  public Set<ProcessDefinition> getProcesses(final String processId, final String queryList) throws RemoteException {
    return getAPI().getProcesses(processId, queryList);
  }

  public Set<ProcessDefinition> getProcesses(final ProcessDefinition.ProcessState processState, 
      final String queryList) throws RemoteException {
    return getAPI().getProcesses(processState, queryList);
  }

  public Set<ProcessDefinition> getProcesses(final String processId, final ProcessDefinition.ProcessState processState, 
      final String queryList) throws RemoteException {
    return getAPI().getProcesses(processId, processState, queryList);
  }

  public ProcessDefinition getPackageProcess(
      final PackageDefinitionUUID packageDefinitionUUID, 
      final String processId, final String queryList) throws PackageNotFoundException, ProcessNotFoundException, RemoteException {
    return getAPI().getPackageProcess(packageDefinitionUUID, processId, queryList);
  }

  public ProcessDefinition getProcess(final String packageId, 
      final String processId, final String version, final String queryList) throws ProcessNotFoundException, RemoteException {
    return getAPI().getProcess(packageId, processId, version, queryList);
  }

  public DataFieldDefinition getProcessDataField(final ProcessDefinitionUUID processDefinitionUUID, 
      final String dataFieldId, final String queryList)
    throws ProcessNotFoundException, DataFieldNotFoundException, RemoteException {
    return getAPI().getProcessDataField(processDefinitionUUID, dataFieldId, queryList);
  }

  public Set<DataFieldDefinition> getProcessDataFields(final ProcessDefinitionUUID processDefinitionUUID, final String queryList)
    throws ProcessNotFoundException, RemoteException {
    return getAPI().getProcessDataFields(processDefinitionUUID, queryList);
  }

  public Set<DataFieldDefinition> getActivityDataFields(final ActivityDefinitionUUID activityDefinitionUUID, 
      final String queryList) throws ActivityDefNotFoundException, RemoteException {
    return getAPI().getActivityDataFields(activityDefinitionUUID, queryList);
  }

  public DataFieldDefinition getActivityDataField(
    final ActivityDefinitionUUID activityDefinitionUUID, final String dataFieldId, final String queryList)
    throws ActivityDefNotFoundException, DataFieldNotFoundException, RemoteException {
    return getAPI().getActivityDataField(activityDefinitionUUID, dataFieldId, queryList);
  }

}


