/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.ejb;

import java.rmi.RemoteException;
import java.util.Collection;
import java.util.Map;
import java.util.Set;

import javax.ejb.SessionBean;
import javax.ejb.SessionContext;

import org.ow2.bonita.facade.exception.ActivityNotFoundException;
import org.ow2.bonita.facade.exception.InstanceNotFoundException;
import org.ow2.bonita.facade.exception.ProcessNotFoundException;
import org.ow2.bonita.facade.exception.TaskNotFoundException;
import org.ow2.bonita.facade.exception.VariableNotFoundException;
import org.ow2.bonita.facade.impl.StandardInternalAPIAccessorImpl;
import org.ow2.bonita.facade.internal.InternalQueryRuntimeAPI;
import org.ow2.bonita.facade.runtime.ActivityBody;
import org.ow2.bonita.facade.runtime.ActivityInstance;
import org.ow2.bonita.facade.runtime.ProcessInstance;
import org.ow2.bonita.facade.runtime.TaskInstance;
import org.ow2.bonita.facade.runtime.TaskState;
import org.ow2.bonita.facade.uuid.ActivityInstanceUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessInstanceUUID;
import org.ow2.bonita.facade.uuid.TaskUUID;

/**
 * @author Pierre Vigneras, Charles Souillard, Guillaume Porcher
 * @date Feb 15, 2008
 */
public class QueryRuntimeAPIBean implements InternalQueryRuntimeAPI, SessionBean {

  protected SessionContext ctx = null;

  protected InternalQueryRuntimeAPI queryRuntimeAPI;

  protected InternalQueryRuntimeAPI getAPI() {
    EJB2SecurityOwner.setUser(this.ctx.getCallerPrincipal().getName());
    if (this.queryRuntimeAPI == null) {
      this.queryRuntimeAPI = new StandardInternalAPIAccessorImpl().getQueryRuntimeAPI();
    }
    return this.queryRuntimeAPI;
  }


  public void ejbCreate() {
  }

  public void ejbActivate() throws RemoteException {

  }

  public void ejbPassivate() throws RemoteException {

  }

  public void ejbRemove() throws RemoteException {

  }

  public void setSessionContext(final SessionContext arg0) throws RemoteException {
    this.ctx = arg0;
  }

  public Set<ActivityInstance<ActivityBody>> getActivityInstances(
      final ProcessInstanceUUID instanceUUID, final String queryList) throws InstanceNotFoundException, RemoteException {
    return getAPI().getActivityInstances(instanceUUID, queryList);
  }

  public Set<ActivityInstance<ActivityBody>> getActivityInstances(
      final ProcessInstanceUUID instanceUUID, final String activityId, 
      final String queryList) throws InstanceNotFoundException, ActivityNotFoundException, RemoteException {
    return getAPI().getActivityInstances(instanceUUID, activityId, queryList);
  }

  public ActivityInstance<ActivityBody> getActivityInstance(
      final ActivityInstanceUUID activityUUID, final String queryList) throws ActivityNotFoundException, RemoteException {
    return getAPI().getActivityInstance(activityUUID, queryList);
  }

  public ProcessInstance getProcessInstance(final ProcessInstanceUUID instanceUUID, 
      final String queryList) throws InstanceNotFoundException, RemoteException {
    return getAPI().getProcessInstance(instanceUUID, queryList);
  }

  public Set<ProcessInstance> getProcessInstances(final String queryList) throws RemoteException {
    return getAPI().getProcessInstances(queryList);
  }

  public Set<ProcessInstance> getProcessInstances(final ProcessDefinitionUUID processUUID, 
      final String queryList) throws ProcessNotFoundException, RemoteException {
    return getAPI().getProcessInstances(processUUID, queryList);
  }

  public ActivityInstance<TaskInstance> getTask(final TaskUUID taskUUID, 
      final String queryList) throws TaskNotFoundException, RemoteException {
    return getAPI().getTask(taskUUID, queryList);
  }

  public Collection<ActivityInstance<TaskInstance>> getTaskList(final ProcessInstanceUUID instanceUUID,
      final TaskState taskState, final String queryList) throws InstanceNotFoundException, RemoteException {
    return getAPI().getTaskList(instanceUUID, taskState, queryList);
  }

  public Collection<ActivityInstance<TaskInstance>> getTaskList(final ProcessInstanceUUID instanceUUID,
      final String userId, final TaskState taskState, final String queryList) throws InstanceNotFoundException, RemoteException {
    return getAPI().getTaskList(instanceUUID, userId, taskState, queryList);
  }

  public Collection<ActivityInstance<TaskInstance>> getTaskList(final TaskState taskState, 
      final String queryList) throws RemoteException {
    return getAPI().getTaskList(taskState, queryList);
  }

  public Collection<ActivityInstance<TaskInstance>> getTaskList(final String userId, 
      final TaskState taskState, final String queryList) throws RemoteException {
    return getAPI().getTaskList(userId, taskState, queryList);
  }

  public Set<ActivityInstance<TaskInstance>> getTasks(
      final ProcessInstanceUUID instanceUUID, final String queryList) throws InstanceNotFoundException, RemoteException {
    return getAPI().getTasks(instanceUUID, queryList);
  }

  public Object getActivityInstanceVariable(final ActivityInstanceUUID activityUUID,
      final String variableId, final String queryList) throws ActivityNotFoundException,
      VariableNotFoundException, RemoteException {
    return getAPI().getActivityInstanceVariable(activityUUID, variableId, queryList);
  }

  public Object getProcessInstanceVariable(final ProcessInstanceUUID instanceUUID, final String variableId, 
      final String queryList) throws InstanceNotFoundException, VariableNotFoundException, RemoteException {
    return getAPI().getProcessInstanceVariable(instanceUUID, variableId, queryList);
  }

  public Map<String, Object> getActivityInstanceVariables(
      final ActivityInstanceUUID activityUUID, final String queryList) throws ActivityNotFoundException, RemoteException {
    return getAPI().getActivityInstanceVariables(activityUUID, queryList);
  }

  public Map<String, Object> getProcessInstanceVariables(
      final ProcessInstanceUUID instanceUUID, final String queryList) throws InstanceNotFoundException, RemoteException {
    return getAPI().getProcessInstanceVariables(instanceUUID, queryList);
  }

  public Object getVariable(final ActivityInstanceUUID activityUUID, 
      final String variableId, 
      final String queryList) throws ActivityNotFoundException, VariableNotFoundException, RemoteException {
    return getAPI().getVariable(activityUUID, variableId, queryList);
  }
  public Map<String, Object> getVariables(final ActivityInstanceUUID activityUUID, 
      final String queryList) throws InstanceNotFoundException, ActivityNotFoundException, RemoteException {
    return getAPI().getVariables(activityUUID, queryList);
  }

}


