package org.ow2.bonita.facade.interceptor;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import javax.interceptor.InvocationContext;

import org.ow2.bonita.facade.impl.StandardInternalAPIAccessorImpl;
import org.ow2.bonita.facade.internal.InternalAPIAccessor;
import org.ow2.bonita.util.BonitaRuntimeException;

/**
 * Interceptor class to redirect ejb3 bean calls to the standalone api
 * @author Thomas Gueze
 *
 */
public class EJB3Interceptor {

  private static final int SUFFIX_LENGTH = "Bean".length();

  private Object getStandaloneAPI(final String className) {
    try {
      final InternalAPIAccessor apiAccessor = new StandardInternalAPIAccessorImpl();
      final Method m = apiAccessor.getClass().getMethod("get" + className);
      return m.invoke(apiAccessor);
    } catch (final Exception e) {
      throw new BonitaRuntimeException("Cannot get the standalone api class", e);
    }
  }

  public Object performInterception(final InvocationContext ctx) throws Exception {
    String className = ctx.getTarget().getClass().getSimpleName();
    className = className.substring(0, className.length() - SUFFIX_LENGTH);
    final Object standaloneAPI = getStandaloneAPI(className);
    Method implMethod = null;
    try {
      implMethod = standaloneAPI.getClass().getMethod(ctx.getMethod().getName(), ctx.getMethod().getParameterTypes());
      return implMethod.invoke(standaloneAPI, ctx.getParameters());
    } catch (final Exception e) {
      if (e instanceof InvocationTargetException && implMethod != null) {
        final Throwable invocationExceptionCause = e.getCause();
        InterceptorUtil.manageInvokeExceptionCause(implMethod, invocationExceptionCause);
      }
      throw new BonitaRuntimeException("Cannot call the method " + ctx.getMethod().getName() + " on the standalone api", e);
    }
  }
}
